/* global style start
	============================================================================================ */

body {
	color: $text-color;
	font-family: $text-font;
	font-weight: 400;
  line-height: 1.625;
  overflow-x: hidden;
}

ul{
  list-style-type: none;
  margin: 0;
  padding: 0;
}

a:hover{
  text-decoration: none;
}

button{
  cursor: pointer;

  &:focus{
    outline: 0;
    box-shadow: none;
  }
}

h1,
h2,
h3,
h4,
h5,
h6 {
	font-family: $title-font;
	color: $title-color;
	line-height: 1.2;
}

h1,
.h1 {
  font-size: 50px;
  font-weight: 700;
}
h2,
.h2 {
  font-size: 30px;
  font-weight: 600;

  @media(min-width: 800px){
    font-size: 40px;
  }

  @media(min-width: 1000px){
    font-size: 50px;
  }
}

a{
  display: inline-block;
}

.dropdown:hover>.dropdown-menu {
  display: block;
  top: 96%;
}

//  owl carousel img size hack
.owl-carousel .owl-stage {
  display: flex;
}

.section-margin{
  margin: 50px 0;

  @media(min-width: 1000px){
    margin: 80px 0;
  }

  @media(min-width: 1250px){
    margin: 120px 0;
  }

  &--large{
    margin: 50px 0;

    @media(min-width: 1000px){
      margin: 80px 0;
    }

    @media(min-width: 1250px){
      margin: 130px 0;
    }
  }
}

.section-padding{
  padding: 50px 0;

  @media(min-width: 1000px){
    padding: 80px 0;
  }

  @media(min-width: 1250px){
    padding: 120px 0;
  }

  &--large{
    padding: 130px 0;
  }
}

.pb-70px{
  padding-bottom: 45px;

  @media(min-width: 1000px){
    padding-bottom: 70px;
  }
}

@media(min-width: 768px){
  .gutters-48 {
    margin-right: -24px;
    margin-left: -24px;
    > [class*="col-"] {
      padding-right: 24px;
      padding-left: 24px;
    }
  }
}


.bg-soapstone{
  background: $soapstone;
}

/* global style end
	============================================================================================ */