//--------- start footer Area -------------//
.footer-area {
	padding: 120px 0px 120px;
	// background: url(../img/footer-bg.png) no-repeat center;
	background: #09152b;
	@media (max-width: 991px) {
		// background: $title-color;
		padding: 60px 0px;
	}
	.single-footer-widget {
		@media (max-width: 991px) {
			margin-bottom: 30px;
		}

		p{
			color: #7b838a;
		}

		h4 {
      font-weight: 600;
			color: $white;
			margin-bottom: 25px;
			@media (max-width: 1024px) {
				font-size: 20px;
			}
			@media (max-width: 991px) {
				margin-bottom: 15px;
			}
		}
		ul {
			li {
				margin-bottom: 10px;
				a {
					@include transition();
					color: $link-color;
					&:hover {
						color: $primary-color;
					}
				}
			}
		}
		.form-wrap {
      margin-top: 25px;
      
      .info{
        color: $primary-color;
      }
		}
		input {
			height: 48px;
			border: none;
			width: 67% !important;
			font-weight: 400;
			background: rgba(255, 255, 255, 0.2);
			color: $white;
			padding-left: 20px;
			border-radius: 0;
			font-size: 14px;
			padding: 10px;
			&:focus {
				outline: none;
				box-shadow: none;
			}
			@include placeholder {
				padding-left: 10px;
				color: $link-color;
			}
		}
		.click-btn {
			color: $title-color;
			border-radius: 0;
			border-top-left-radius: 0px;
			border-bottom-left-radius: 0px;
			padding: 6px 24px;
			border: 0;
			background: $white;
			position: relative;
      left: 0;
      text-transform: capitalize;
			&:focus {
				outline: none;
				box-shadow: none;
      }
      
      @media(max-width: 375px){
        margin-top: 10px;
      }

			@media(min-width: 400px){
				left: -50px;
			}
		}
	}
	.footer-bottom {
		margin-top: 70px;
		@media (max-width: 991px) {
			margin-top: 20px;
		}
		p {
			color: $white;

			a{
				color: $primary-color;
			}
		}
		// span {
		// 	font-weight: 700;
		// }
		.footer-social {
			text-align: center;
			@media (max-width: 991px) {
				text-align: left;
				margin-top: 30px;
			}
			a {
				background: rgba(255, 255, 255, 0.15);
				margin-left: 3px;
				width: 32px;
				color: $white;
				display: inline-grid;
				text-align: center;
				height: 32px;
				align-content: center;
				@include transition();
				&:hover {
					// @extend .gradient-bg;
          background: $white;
          color: $primary-color;
				}

				i,span{
					font-size: 14px;
				}
			}
		}
	}
}
//--------- end footer Area -------------//
