/* banner section start
	============================================================================================ */
.banner-area{
  position: relative;
  height: 380px;
  z-index: 1;

  @media(min-width: 1000px){
    height: 520px;
  }

  &::after{
    content: "";
    display: block;
    background: rgba(5, 10, 52, 0.6);
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    z-index: -1;
  }

  &.contact{
    background: url(../img/banner/blog.png) left center no-repeat;
    background-size: cover;
  }

  &.about{
    background: url(../img/banner/blog.png) left center no-repeat;
    background-size: cover;
  }

  &.service{
    background: url(../img/banner/blog.png) left center no-repeat;
    background-size: cover;
  }

  &.team{
    background: url(../img/banner/blog.png) left center no-repeat;
    background-size: cover;
  }

  &.pricing{
    background: url(../img/banner/blog.png) left center no-repeat;
    background-size: cover;
  }
  
  &__content{
    position: absolute;
    width: 100%;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
    margin-top: 70px;

    h1{
      font-size: 50px;
      font-weight: 600;
      margin-bottom: 2px;
      color: #fff;
    }
  }
}

.banner-breadcrumb{
  display: inline-block;
  
  .breadcrumb{
    background: transparent;
    padding: 0;

    &-item{
      padding: .1rem;

      a{
        text-transform: capitalize;
        color: #fff;
      }

      &+.breadcrumb-item::before{
        color: #fff;
        padding-right: .1rem;
      }

      &.active{
        color: #fff;
      }
    }
  }
}


.hero-banner{
  background: #fff9f7;

  &__img{
    @media(min-width: 1200px){
      position: absolute;
      top: 0;
      left: -120px;
    }
  }

  &__content{
    padding-top: 38px;
    padding-bottom: 50px;

    @media(min-width: 768px){
      padding-top: 120px;
    }

    @media(min-width: 991px){
      padding-top: 195px;
    }

    @media(min-width: 1200px){
      padding-top: 295px;
      padding-bottom: 195px;
    }

    h1{
      font-size: 28px;
      margin-bottom: 25px;

      @media(min-width: 991px){
        font-size: 50px;
      }
    }

    p{
      margin-bottom: 35px;
    }
  }

  &__video{
    background: url(../img/home/play-icon.png) left center no-repeat;
    margin-left: 25px;
    padding: 12px 5px 12px 45px !important;
    // background-size: cover;

    img{
      margin-right: 10px;
    }
  }
}
/* banner section end
	============================================================================================ */